Submit changes
--------------

Before anything, please keep in mind the following. If one or more of those conditions are not filled.
Your Pull Request to PyFunceble may not be merged.

The :code:`master` branch is used only for releasing a new or stable version of the code.
That's why we require that all contributions/modifications must be done under the :code:`dev` or a new branch.

In order to gain some time and also understand what you are working on, your pull requests
submission as long as your commit descriptions should be clear and complete as much as possible.
We do an exception to commit with minor changed but big changes should have a complete description.
Please ensure to use the following method when committing a big change.
